pub struct DirectConfig {
pub name: String,
pub timeout_ms: Option<u64>,
pub block: Option<bool>,
pub fail_if_no_consumers: Option<bool>,
pub bridge_error_handler: Option<bool>,
pub exchange_pattern: Option<String>,
}Expand description
Configuration for Direct endpoints parsed from URIs.
URI format: direct:name[?timeout_ms=30000]
Example: direct:foo creates an endpoint named “foo”
Fields
name: StringEndpoint name (path portion).
timeout_ms: Option<u64>Timeout in milliseconds for producer call(). Defaults to 30 000 ms.
block: Option<bool>When false, the producer returns immediately if no consumer is registered. TODO(DIR-001): implement non-blocking send
fail_if_no_consumers: Option<bool>When false, skip readiness error if no consumer registered.
bridge_error_handler: Option<bool>TODO(DIR-005): implement bridgeErrorHandler routing
exchange_pattern: Option<String>TODO(DIR-005): implement exchangePattern override
Implementations
Sourceimpl DirectConfig
impl DirectConfig
pub fn from_uri(uri: &str) -> Result<Self, CamelError>